cvs: pear /HTTP_WebDAV_Server Server.php

[email protected] ("Hartmut Holzgraefe")
Newsgroups php.pear.cvs
Message-ID <cvshholzgra1208919747@cvsserver>
hholzgra		Wed Apr 23 03:02:27 2008 UTC

  Modified files:              
    /pear/HTTP_WebDAV_Server	Server.php 
  Log:
  spelling in comments and private method name
  
  
http://cvs.php.net/viewvc.cgi/pear/HTTP_WebDAV_Server/Server.php?r1=1.72&r2=1.73&diff_format=u
Index: pear/HTTP_WebDAV_Server/Server.php
diff -u pear/HTTP_WebDAV_Server/Server.php:1.72 pear/HTTP_WebDAV_Server/Server.php:1.73
--- pear/HTTP_WebDAV_Server/Server.php:1.72	Wed Apr 23 02:56:05 2008
+++ pear/HTTP_WebDAV_Server/Server.php	Wed Apr 23 03:02:26 2008
@@ -1,4 +1,4 @@
-<?php // $Id: Server.php,v 1.72 2008/04/23 02:56:05 hholzgra Exp $
+<?php // $Id: Server.php,v 1.73 2008/04/23 03:02:26 hholzgra Exp $
 /*
    +----------------------------------------------------------------------+
    | Copyright (c) 2002-2007 Christian Stocker, Hartmut Holzgraefe        |
@@ -721,7 +721,7 @@
             /* TODO right now the user implementation has to make sure
              collections end in a slash, this should be done in here
              by checking the resource attribute */
-            $href = $this->_mergePathes($this->_SERVER['SCRIPT_NAME'], $path);
+            $href = $this->_mergePaths($this->_SERVER['SCRIPT_NAME'], $path);
 
             /* minimal urlencoding is needed for the resource path */
             $href = $this->_urlencode($href);
@@ -869,7 +869,7 @@
 
             echo "<D:multistatus xmlns:D=\"DAV:\">\n";
             echo " <D:response>\n";
-            echo "  <D:href>".$this->_urlencode($this->_mergePathes($this->_SERVER["SCRIPT_NAME"], $this->path))."</D:href>\n";
+            echo "  <D:href>".$this->_urlencode($this->_mergePaths($this->_SERVER["SCRIPT_NAME"], $this->path))."</D:href>\n";
 
             foreach ($options["props"] as $prop) {
                 echo "   <D:propstat>\n";
@@ -1033,7 +1033,7 @@
             if (false === $status) {
                 $this->http_status("404 not found");
             } else {
                 // TODO: check setting of headers in various code pathes above
                 $this->http_status("$status");
             }
         }
@@ -2096,13 +2096,13 @@
     }
 
     /**
      * Merge two pathes, make sure there is exactly one slash between them
      *
      * @param  string  parent path
      * @param  string  child path
      * @return string  merged path
      */
-    function _mergePathes($parent, $child) 
+    function _mergePaths($parent, $child) 
     {
         if ($child{0} == '/') {
             return $this->_unslashify($parent).$child;
@@ -1033,7 +1033,7 @@
                 $this->http_status("404 not found");
             } else {
-                // TODO: check setting of headers in various code pathes above
+                // TODO: check setting of headers in various code paths above
                 $this->http_status("$status");
             }
@@ -2096,13 +2096,13 @@
 
     /**
-     * Merge two pathes, make sure there is exactly one slash between them
+     * Merge two paths, make sure there is exactly one slash between them
      *
      * @param  string  parent path
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.